

set -ex



pytest -vv
test ! -f /var/folders/sy/f16zz6x50xz3113nwtb9bvq00000gp/T/abs_fcst21ovbt/croot/conda-standalone_1715892193813/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho/bin/codesign
exit 0
